shithub: hugo

Download patch

ref: 342b6fe8a584a84b83159da430773fcdb7b174e4
parent: 4ad39445efc0f69cb63fc3c76a9e0db579527ab2
author: Bjørn Erik Pedersen <[email protected]>
date: Fri Oct 28 06:35:19 EDT 2016

Make it clear that Path is relative to content root

Fixes #2290

--- a/source/file.go
+++ b/source/file.go
@@ -25,7 +25,7 @@
 // File represents a source content file.
 // All paths are relative from the source directory base
 type File struct {
-	relpath     string // Original relative path, e.g. content/foo.txt
+	relpath     string // Original relative path, e.g. section/foo.txt
 	logicalName string // foo.txt
 	baseName    string // `post` for `post.md`, also `post.en` for `post.en.md`
 	Contents    io.Reader
@@ -101,8 +101,8 @@
 	return f.Extension()
 }
 
-// Path gets the relative path including file name and extension from
-// the base of the source directory.
+// Path gets the relative path including file name and extension.
+// The directory is relative to the content root.
 func (f *File) Path() string {
 	return f.relpath
 }
--- a/hugolib/page_test.go
+++ b/hugolib/page_test.go
@@ -643,8 +643,8 @@
 	assertFunc := func(t *testing.T, ext string, pages Pages) {
 		p := pages[0]
 
-		// issue #2290: No /content in Path
-		// require.Equal(t, "asdf", p.Path())
+		// issue #2290: Path is relative to the content dir and will continue to be so.
+		require.Equal(t, filepath.FromSlash(fmt.Sprintf("p0.%s", ext)), p.Path())
 		assert.False(t, p.IsHome)
 		checkPageTitle(t, p, "Simple")
 		checkPageContent(t, p, normalizeExpected(ext, "<p>Simple Page</p>\n"))
@@ -654,7 +654,11 @@
 		checkTruncation(t, p, false, "simple short page")
 	}
 
-	testAllMarkdownEnginesForPages(t, assertFunc, nil, simplePage)
+	settings := map[string]interface{}{
+		"contentDir": "mycontent",
+	}
+
+	testAllMarkdownEnginesForPages(t, assertFunc, settings, simplePage)
 }
 
 func TestSplitSummaryAndContent(t *testing.T) {